/*
 -------------------------------------------------------------------------------
 | Producer - Copyright (C) 2001-2007  Don Burns                               |
 |                                                                             |
 | This library is free software; you can redistribute it and/or modify        |
 | it under the terms of the GNU Lesser General Public License as published    |
 | by the Free Software Foundation; either version 3 of the License, or        |
 | (at your option) any later version.                                         |
 |                                                                             |
 | This library is distributed in the hope that it will be useful, but         |
 | WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  |
 | or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public     |
 | License for more details.                                                   |
 |                                                                             |
 | You should have received a copy of the GNU Lesser General Public License    |
 | along with this software; if not, write to the Free Software Foundation,    |
 | Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.               |
 |                                                                             |
 -------------------------------------------------------------------------------
 */


#ifndef PRODUCER_INPUT_AREA_DEF
#define PRODUCER_INPUT_AREA_DEF 1

#include <Producer/Export.h>
#include <Producer/Referenced.h>

#include <vector>

#include <Producer/Types.h>

namespace Producer{

class RenderSurface;


class PR_EXPORT InputArea: public Referenced
{
    public:

        InputArea();

        void    addRenderSurface( Producer::RenderSurface *rs );
        bool    isRealized();
        bool    waitForRealize();
    
        unsigned int getNumRenderSurfaces();
        RenderSurface *getRenderSurface(unsigned int index);

        unsigned int getNumWindows();
        Window  getWindow(unsigned int index);
        
        void    normalizeMouseMotion( Window win, int mx, int my, float &nmx, float &nmy);
        void    transformMouseMotion( Window win, int mx, int my, float &nmx, float &nmy);

        void    normalizeXY( float &x, float &y );

        void    getExtents( float &minX, float &maxX, float &minY, float &maxY );
        void    getCenter( float &cx, float &cy );


    protected:

        virtual ~InputArea();

        std::vector<RenderSurface *> _mapdata;

        bool _init();
        bool _initialized;
        float _minX, _maxX, _minY, _maxY;
        bool    _waitForRealize();

};

}

#endif
