/*
 -------------------------------------------------------------------------------
 | Producer - Copyright (C) 2001-2007  Don Burns                               |
 |                                                                             |
 | This library is free software; you can redistribute it and/or modify        |
 | it under the terms of the GNU Lesser General Public License as published    |
 | by the Free Software Foundation; either version 3 of the License, or        |
 | (at your option) any later version.                                         |
 |                                                                             |
 | This library is distributed in the hope that it will be useful, but         |
 | WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  |
 | or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public     |
 | License for more details.                                                   |
 |                                                                             |
 | You should have received a copy of the GNU Lesser General Public License    |
 | along with this software; if not, write to the Free Software Foundation,    |
 | Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.               |
 |                                                                             |
 -------------------------------------------------------------------------------
 */


#ifndef PRODUCER_WINDOW3D_DEF
#define PRODUCER_WINDOW3D_DEF 1

#include <Producer/Export.h>
#include <Producer/Referenced.h>
#include <Producer/KeyboardMouse.h>
#include <Producer/Trackball.h>

#include <string>


namespace Producer {

class PR_EXPORT Window3D : public Referenced
{
    public :
        class KeyboardCallback : public Referenced
        {
            public:
                KeyboardCallback() {}
                virtual void operator()(KeyCharacter) = 0;
            protected:
                virtual ~KeyboardCallback() {}
        };

        Window3D( 
            const std::string name="Producer::Window3D", 
            int posx = 0,
            int posy = 0,
            unsigned int width =(unsigned int)-1, 
            unsigned int height=(unsigned int)-1, 
            unsigned int parent=0 );

        unsigned int width( void ) const;
        unsigned int height( void ) const;
        void getDimensions( unsigned int &width, unsigned int &height );
        void swapBuffers( void );
        void sync( int n=0 );

        void setKeyboardCallback( KeyboardCallback *);
        int mouseX(void);
        int mouseY(void);
        unsigned int mouseButton(void);
        void enableTrackball( void );
        void disableTrackball( void );
        Matrix::value_type *getTrackballMatrix(void);
        void setTrackballScale( float s );

        Trackball &getTrackball();
    
        bool done();

        ~Window3D() ;

    private :

        // ensure that you can't copy Window3D.
        Window3D( const Window3D& ) : Referenced() {}
        Window3D& operator = ( const Window3D& ) { return *this;}

        class Implementation;
        Implementation *_implementation;
};

}

#endif

