/*
 -------------------------------------------------------------------------------
 | Producer - Copyright (C) 2001-2007  Don Burns                               |
 |                                                                             |
 | This library is free software; you can redistribute it and/or modify        |
 | it under the terms of the GNU Lesser General Public License as published    |
 | by the Free Software Foundation; either version 3 of the License, or        |
 | (at your option) any later version.                                         |
 |                                                                             |
 | This library is distributed in the hope that it will be useful, but         |
 | WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  |
 | or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public     |
 | License for more details.                                                   |
 |                                                                             |
 | You should have received a copy of the GNU Lesser General Public License    |
 | along with this software; if not, write to the Free Software Foundation,    |
 | Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.               |
 |                                                                             |
 -------------------------------------------------------------------------------
 */

#ifndef QPRODUCER_DEF
#define QPRODUCER_DEF 1

#include <qgl.h>

#include <Producer/Camera.h>
#include <Producer/Trackball.h>
#include <osgDB/ReadFile>

#include <ProducerOSG/OsgSceneHandler.h>

class QProducer : public QGLWidget, public Producer::RenderSurface
{
    public:
        QProducer( QWidget *parent=0, const char *name=0 );

        virtual bool realize( Producer::VisualChooser * =NULL, Producer::GLContext =0 ) ;
        virtual bool makeCurrent( bool ) ;
        void setTimerInterval( int i ) { _timer_interval = i; }
        int getTimerInterval() { return _timer_interval; }

    protected:
        void initializeGL();
        void resizeGL( int, int );
        void paintGL();
        void timerEvent( QTimerEvent * );

        virtual void keyPressEvent( QKeyEvent* event );
        virtual void keyReleaseEvent( QKeyEvent* event );
        virtual void mousePressEvent( QMouseEvent* event );
        virtual void mouseReleaseEvent( QMouseEvent* event );
        virtual void mouseMoveEvent( QMouseEvent* event );

    private:

        Producer::ref_ptr<Producer::Camera> _camera;
        Producer::ref_ptr<Producer::Trackball> _trackball;

        int _timer_interval;
        int _mx, _my;
        unsigned int _mbutton;

        void _normalizeMouseXY( int x, int, float &nx, float &ny );
};

#endif
